﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using Infragistics;
using Infragistics.Controls.Charts;

namespace RealTimeStackedAreaSeriesChart
{
    using System.Windows.Threading;

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public ObservableCollection<CategoryData> RetVal { get; set; }

        private DispatcherTimer timer;

        public MainWindow()
        {
            InitializeComponent();
            RetVal = new ObservableCollection<CategoryData>();

            this.timer = new DispatcherTimer();
            this.timer.Interval = TimeSpan.FromMilliseconds(1000);
            this.timer.Tick += this.OnTimer;
        }

        private void OnTimer(object sender, EventArgs e)
        {
            SimulateData();
        }

        private void SimulateData()
        {
            int stIdx = new Random().Next(1, 4);
            RetVal[stIdx].Value = new Random().Next(60, 1300);

            //NOTE:
            //Found alternate solution that adding and removing series works, but don't want to do that until otherwise no solution available

        }

        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            GroupBy gb = new GroupBy();

            gb.GroupMemberPath = "Category";
            gb.KeyMemberPath = "SeriesName";
            gb.ValueMemberPath = "Value";

            RetVal = StationDataCollection.GetItemSource();
            gb.ItemsSource = RetVal;

            Infragistics.Controls.Charts.NumericYAxis yAxis = new NumericYAxis();

            CategoryXAxis xAxis = new CategoryXAxis();
            xAxis.ItemsSource = gb;
            // xAxis.Label = Resources["labels"] as DataTemplate;
            xAxis.Label = "{Key}";
            this.theChart.Axes.Add(xAxis);
            this.theChart.Axes.Add(yAxis);

            StackedColumnSeries series = new StackedColumnSeries();

            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.ItemsSource = gb;
            series.AutoGenerateSeries = true;
            theChart.Series.Add(series);
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
             this.timer.Start();
        }

        private void Button2_Click(object sender, RoutedEventArgs e)
        {
             this.timer.Stop();
        }
    }

    public class StationDataCollection
    {

        public static ObservableCollection<CategoryData> GetItemSource()
        {

            DateTime dt = DateTime.Now;

            ObservableCollection<CategoryData> retVal = new ObservableCollection<CategoryData>();


            retVal.Add(new CategoryData("Series 1", 1370, "Category 1"));
            retVal.Add(new CategoryData("Series 2", 1100, "Category 1"));

            retVal.Add(new CategoryData("Series 1", 70, "Category 2"));
            retVal.Add(new CategoryData("Series 2", 1400, "Category 2"));

            retVal.Add(new CategoryData("Series 1", 670, "Category 3"));
            retVal.Add(new CategoryData("Series 2", 800, "Category 3"));

            retVal.Add(new CategoryData("Series 1", 1270, "Category 4"));
            retVal.Add(new CategoryData("Series 2", 200, "Category 4"));
            
            return retVal;
        }
    }

    public class CategoryData
    {

        public string Category { get; set; }

        public string SeriesName { get; set; }

        public double Value { get; set; }

        public CategoryData(string seriesName, double value, string category)
        {
            SeriesName = seriesName;
            Value = value;
            Category = category;
        }
       
    }
}